@@ -1,7 +1,7 @@
 package Scalar::Util::Numeric::PP;
 
-our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -21,21 +21,21 @@ our @EXPORT_OK = qw(
 sub isint {
     local $_ = shift;
     return 0 unless defined;
-    return 1 if /\A[+-]?(?:0|[1-9][0-9]*)\z/;
+    return 1 if /\A\s*[+-]?(?:0|[1-9][0-9]*)\s*\z/s;
     0;
 }
 
 sub isnan($) {
     local $_ = shift;
     return 0 unless defined;
-    return 1 if /\A\s*[+-]?nan\s*\z/i;
+    return 1 if /\A\s*[+-]?nan\s*\z/is;
     0;
 }
 
 sub isinf($) {
     local $_ = shift;
     return 0 unless defined;
-    return 1 if /\A\s*[+-]?inf(?:inity)?\s*\z/i;
+    return 1 if /\A\s*[+-]?inf(?:inity)?\s*\z/is;
     0;
 }
 
@@ -57,9 +57,9 @@ sub isnum($) {
 sub isfloat($) {
     local $_ = shift;
     return 0 unless defined;
-    return 1 if /\A[+-]?
+    return 1 if /\A\s*[+-]?
                  (?: (?:0|[1-9][0-9]*)(\.[0-9]+)? | (\.[0-9]+) )
-                 ([eE][+-]?[0-9]+)?\z/x && $1 || $2 || $3;
+                 ([eE][+-]?[0-9]+)?\s*\z/sx && $1 || $2 || $3;
     return 1 if isnan($_) || isinf($_);
     0;
 }
@@ -79,7 +79,7 @@ Scalar::Util::Numeric::PP - Pure-perl drop-in replacement/approximation of Scala
 
 =head1 VERSION
 
-This document describes version 0.03 of Scalar::Util::Numeric::PP (from Perl distribution Scalar-Util-Numeric-PP), released on 2015-06-16.
+This document describes version 0.04 of Scalar::Util::Numeric::PP (from Perl distribution Scalar-Util-Numeric-PP), released on 2016-01-22.
 
 =head1 SYNOPSIS
 
@@ -105,12 +105,6 @@ Not all functions from Scalar::Util::Numeric have been provided.
 
 =head2 isnan
 
-=head1 SEE ALSO
-
-L<Data::Sah>
-
-L<Scalar::Util::Numeric>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Scalar-Util-Numeric-PP>.
@@ -127,13 +121,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Data::Sah>
+
+L<Scalar::Util::Numeric>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
